@@ -11,7 +11,7 @@ extends qw(
     TAP::Formatter::Console
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 has _test_results => (
     is      => 'rw',
@@ -32,10 +32,10 @@ sub open_test {
 sub summary {
     my ($self, $aggregate) = @_;
 
-    $self->_save_results('results.xml');
+    $self->_save_results( $ENV{TAP_FORMATTER_BAMBOO_OUTFILE} || 'results.xml');
 
     return if $self->silent();
-
+     
     print { $self->stdout } "ALL DONE\n";
 }
 
@@ -125,7 +125,9 @@ This module is based on TAP::Formatter::JUnit by Graham TerMarsch
 
 =over
 
-=item * resulting XML is saved in results.xml instead of putting it to the stdout
+=item * if environment variable TAP_FORMATTER_BAMBOO_OUTFILE is present then it
+will be used as filepath for output XML (otherwise "results.xml file will be
+created in current directory)
 
 =item * information about passing/failing tests is put to the STDOUT/STDERR respectively,
 so it can be watched in Bamboo's build logs (also live during build)
